{
  description = "A very basic flake";

  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs?ref=nixos-unstable";
  };

  outputs = { self, nixpkgs }: {
    packages.x86_64-linux = let
      archpkgs = nixpkgs.legacyPackages.x86_64-linux;
      lib = nixpkgs.lib;
    in {
      proxmark = archpkgs.stdenv.mkDerivation rec {
        pname = "proxmark3-rrg";
        version = "4.19552";

        src = archpkgs.fetchFromGitHub {
          owner = "RfidResearchGroup";
          repo = "proxmark3";
          rev = "v${version}";
          sha256 = "sha256-5Rlw5QlceQGiIuVFNZhyrszCdG+idFo8Vvps46VJSlE=";
        };

        nativeBuildInputs = with archpkgs; [ pkg-config gcc-arm-embedded ];
        buildInputs = with archpkgs; [ lz4 zlib bluez5 readline bzip2 openssl ];

        makeFlags = [
          "PLATFORM=PM3GENERIC"
          "PLATFORM_EXTRAS="
        ];

        installPhase = ''
          mkdir -p $out/misc
          cp -r * $out/misc
          install -Dt $out/bin client/proxmark3
          install -Dt $out/firmware bootrom/obj/bootrom.elf armsrc/obj/fullimage.elf
        '';

        meta = with lib; {
          description = "Client for proxmark3, powerful general purpose RFID tool";
          homepage = "https://rfidresearchgroup.com/";
          license = licenses.gpl2Plus;
          maintainers = with maintainers; [ nyanotech ];
        };
      };

    };
    formatter.x86_64-linux = nixpkgs.legacyPackages.x86_64-linux.nixpkgs-fmt;
  };
}
